import matplotlib.cm
import numpy as np
from wela.figs2pdf import figs2pdf
from wela.dataloader import dataloader
from wela.sorting import sort_by_maximum

from wela.plotting import kymograph, plot_lineage

datasets = ["Pdr5_3_11_22"]
for dataname in datasets:
    # load data
    dl = dataloader(".", "/Users/pswain/wip/tsv_data/pdr_with_gr/")
    dl.load(dataname, use_tsv=True, hours=False)
    dl.df.time = dl.df.time / 60
    title = dataname.split(".")[0]
    # although only one group for this data
    groups = dl.df.group.unique()
    # standard kymographs
    kymograph(dl.df, hue="buddings", title=title)
    kymograph(dl.df, hue="median_GFP", title=title, buddings=True)
    kymograph(
        dl.df,
        hue="bud_growth_rate",
        title=title,
        vmin=-50,
        vmax=50,
        cmap=matplotlib.cm.Spectral,
    )
    # sorted kymograph
    t, data = dl.get_time_series("median_GFP", group=groups[0])
    # sort by mean median_GFP over first five hours
    sort_order = sort_by_maximum(data[:, t < 5], np.nanmean)
    kymograph(
        dl.df,
        "median_GFP",
        group=groups[0],
        buddings=True,
        sort_order=sort_order,
        title=title,
    )


if False:
    figs2pdf("fluconazole")
    plot_lineage(dl.ids[34], dl.df)
