from aliby.utils.argo import Argo
import pandas as pd


def search_OMERO(startdate, tags=None):
    """
    Search OMERO database for experiments.

    Arguments
    ---------
    startdate : tuple
        Earliest date from which to search for experiments,
        such as (2019, 10, 30)
    tags:   string
        List of strings to select experiments.

    Returns
    -------
    resdf: Pandas dataframe
    """
    argo = Argo(
        host="staffa.bio.ed.ac.uk",
        user="upload",
        password="gothamc1ty",
        min_date=startdate,
    )
    argo.load()
    if tags:
        argo.tags(tags)

    tups = [
        (
            d.getId(),
            d.getName(),
            d.getDate().strftime("%x"),
            d.getDescription(),
        )
        for d in argo.dsets
    ]
    resdf = pd.DataFrame(
        tups[::-1], columns=["ID", "Name", "Date", "Description"]
    )
    return resdf
