from pathlib import Path

import h5py
from postprocessor.core.postprocessing import (
    PostProcessor,
    PostProcessorParameters,
)


def add_bud_fluorescence(h5dirpath, signals=["/extraction/GFP/max/median"]):
    """
    Re-run postprocessing to add bud fluorescence to an h5 file.

    Parameters
    ----------
    filepath: str or Path object
        Location of the h5 file
    signals: list of str
        The signals to find for the buds as paths in the h5 file.
        E.g. ["/extraction/GFP/max/median", "/extraction/mCherry/max/median"]
    """
    # add new bud_metrics to params
    params = PostProcessorParameters.default()
    params_dict = params.to_dict()
    print("Bud signals to add:")
    for signal in signals:
        print("\t", signal)
        params_dict["targets"]["processes"].append(["bud_metric", [signal]])
    new_params = params.from_dict(params_dict)
    # find h5 files
    if isinstance(h5dirpath, str):
        h5dirpath = Path(h5dirpath)
    h5files = [f.name for f in h5dirpath.glob("*.h5") if f.is_file()]
    # re-run postprocessing for each file
    for h5file in h5files:
        filepath = Path(h5dirpath / h5file)
        # open h5 file for re-writing
        with h5py.File(filepath, "a") as f:
            print(f"re-processing {str(h5file)}")
            if "postprocessing" in f:
                del f["/postprocessing"]
            if "modifiers" in f:
                del f["/modifiers"]
            # re-run postprocessor
            pp = PostProcessor(filepath, new_params)
            pp.run()
