import numpy as np


def sort_by_budding(buddings, bud_number=0):
    """Return indices for each cell when a particular budding occurs."""
    bud_indices = np.transpose(np.nonzero(buddings))
    particular_bud_indices = []
    for cell_i in range(buddings.shape[0]):
        # find particular bud for this cell
        cell_buds = bud_indices[bud_indices[:, 0] == cell_i, :]
        if bud_number < cell_buds.shape[0]:
            particular_bud_indices.append(cell_buds[bud_number][1])
        else:
            particular_bud_indices.append(np.nan)
    # arrange by earliest bud
    sort_order = np.argsort(particular_bud_indices)
    return sort_order


def sort_by_maximum(data, byfunction, reverse=False):
    """
    Return indices of cells sorted by largest value.

    Any cells that have all NaN values are placed last.
    """
    sort_order = np.argsort(byfunction(data, axis=1))
    if reverse:
        return sort_order[::-1]
    else:
        return sort_order


def not_all_nan(data):
    """Find rows that are not all NaN."""
    indices = ~np.all(np.isnan(data), axis=1)
    return indices
